@@ -3,7 +3,7 @@ import matplotlib.pyplot as plt
 from mpl_toolkits.basemap import Basemap as Basemap
 
 
-def draw_nx(G, llon=10, llat=40, ulon=30, ulat=55, dlon=1, dlat=1, ns=10, nc='red', fs=10):
+def draw_nx(G, llon=10, llat=40, ulon=30, ulat=55, dlon=1, dlat=1, ns=10, nc='red', fs=10, prefix=None ):
     m = Basemap(
         projection='merc',
         llcrnrlon=-llon,
@@ -41,7 +41,8 @@ def draw_nx(G, llon=10, llat=40, ulon=30, ulat=55, dlon=1, dlat=1, ns=10, nc='re
         pos[node] = [mx[i], my[i]]
         i += 1
 
-    nx.draw_networkx(G, pos, node_size=ns, node_color=nc, font_size=fs)
+    nx.draw_networkx(G, pos, node_size=ns, node_color=nc, font_size=fs,
+    labels={n:prefix+n for n in G})
 
     m.drawcountries()
     m.drawstates()
